[Libreoffice-commits] core.git: canvas/source chart2/source cppuhelper/source cppu/source cui/source dbaccess/source desktop/test filter/source framework/inc framework/source include/cppuhelper include/rtl include/sfx2 include/svx reportbuilder/java sc/source sd/source stoc/source svx/sdi svx/source sw/inc sw/source toolkit/source unotools/source

Julien Nabet serval2412 at yahoo.fr
Wed Feb 18 13:00:40 PST 2015


 canvas/source/directx/dx_9rm.cxx                                                                    |    2 +-
 canvas/source/directx/dx_vcltools.cxx                                                               |    6 +++---
 chart2/source/inc/NameContainer.hxx                                                                 |    2 +-
 cppu/source/typelib/typelib.cxx                                                                     |    8 ++++----
 cppuhelper/source/propshlp.cxx                                                                      |    6 +++---
 cui/source/dialogs/cuihyperdlg.cxx                                                                  |    4 ++--
 cui/source/dialogs/hldocntp.cxx                                                                     |    2 +-
 cui/source/dialogs/hldoctp.cxx                                                                      |    2 +-
 cui/source/dialogs/hlmailtp.cxx                                                                     |    2 +-
 cui/source/dialogs/hlmarkwn.cxx                                                                     |    2 +-
 dbaccess/source/ui/inc/RelationDlg.hxx                                                              |    4 ++--
 dbaccess/source/ui/inc/ScrollHelper.hxx                                                             |    2 +-
 dbaccess/source/ui/inc/UITools.hxx                                                                  |    2 +-
 desktop/test/deployment/options/handler/com/sun/star/comp/extensionoptions/OptionsEventHandler.java |    2 +-
 filter/source/pdf/pdfexport.cxx                                                                     |    2 +-
 framework/inc/macros/xinterface.hxx                                                                 |   10 +++++-----
 framework/source/fwi/uielement/constitemcontainer.cxx                                               |    6 +++---
 include/cppuhelper/propshlp.hxx                                                                     |    4 ++--
 include/rtl/strbuf.hxx                                                                              |    2 +-
 include/rtl/ustrbuf.hxx                                                                             |    2 +-
 include/sfx2/sfxuno.hxx                                                                             |    2 +-
 include/svx/sdr/overlay/overlayobject.hxx                                                           |    2 +-
 reportbuilder/java/org/libreoffice/report/InputRepository.java                                      |    2 +-
 reportbuilder/java/org/libreoffice/report/OutputRepository.java                                     |    2 +-
 sc/source/ui/view/printfun.cxx                                                                      |    4 ++--
 sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx                                              |    2 +-
 stoc/source/javaloader/javaloader.cxx                                                               |    2 +-
 svx/sdi/fmslots.sdi                                                                                 |    2 +-
 svx/source/fmcomp/gridctrl.cxx                                                                      |    2 +-
 sw/inc/tox.hxx                                                                                      |    2 +-
 sw/source/core/inc/ptqueue.hxx                                                                      |    2 +-
 sw/source/uibase/app/docsh2.cxx                                                                     |    2 +-
 sw/source/uibase/uiview/view2.cxx                                                                   |    2 +-
 toolkit/source/awt/vclxtoolkit.cxx                                                                  |    2 +-
 unotools/source/config/fontoptions.cxx                                                              |    2 +-
 unotools/source/config/localisationoptions.cxx                                                      |    2 +-
 36 files changed, 53 insertions(+), 53 deletions(-)

New commits:
commit 48f0a5ed3501e0b0a55cc71f85b4d1aee5a9f4ed
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Wed Feb 18 21:58:05 2015 +0100

    Typos
    
    Change-Id: I845a85e1aad4a0708f2b43f7d94606b4b5513ee4

diff --git a/canvas/source/directx/dx_9rm.cxx b/canvas/source/directx/dx_9rm.cxx
index e9fd666..b9ee883 100644
--- a/canvas/source/directx/dx_9rm.cxx
+++ b/canvas/source/directx/dx_9rm.cxx
@@ -153,7 +153,7 @@ namespace dxcanvas
             COMReference<IDirect3DTexture9> getTexture() const;
 
         private:
-            /// Guard local methods against concurrent acces to RenderModule
+            /// Guard local methods against concurrent access to RenderModule
             class ImplRenderModuleGuard : private ::boost::noncopyable
             {
             public:
diff --git a/canvas/source/directx/dx_vcltools.cxx b/canvas/source/directx/dx_vcltools.cxx
index 9943257..f65b5fc 100644
--- a/canvas/source/directx/dx_vcltools.cxx
+++ b/canvas/source/directx/dx_vcltools.cxx
@@ -174,7 +174,7 @@ namespace dxcanvas
 
                 ENSURE_OR_THROW( pReadAccess.get() != NULL,
                                   "::dxcanvas::tools::bitmapFromVCLBitmapEx(): "
-                                  "Unable to acquire read acces to bitmap" );
+                                  "Unable to acquire read access to bitmap" );
 
                 if( rBmpEx.IsAlpha() )
                 {
@@ -200,7 +200,7 @@ namespace dxcanvas
 
                     ENSURE_OR_THROW( pAlphaReadAccess.get() != NULL,
                                       "::dxcanvas::tools::bitmapFromVCLBitmapEx(): "
-                                      "Unable to acquire read acces to alpha" );
+                                      "Unable to acquire read access to alpha" );
 
                     ENSURE_OR_THROW( pAlphaReadAccess->GetScanlineFormat() == BMP_FORMAT_8BIT_PAL ||
                                       pAlphaReadAccess->GetScanlineFormat() == BMP_FORMAT_8BIT_TC_MASK,
@@ -342,7 +342,7 @@ namespace dxcanvas
 
                     ENSURE_OR_THROW( pMaskReadAccess.get() != NULL,
                                       "::dxcanvas::tools::bitmapFromVCLBitmapEx(): "
-                                      "Unable to acquire read acces to mask" );
+                                      "Unable to acquire read access to mask" );
 
                     ENSURE_OR_THROW( pMaskReadAccess->GetScanlineFormat() == BMP_FORMAT_1BIT_MSB_PAL,
                                       "::dxcanvas::tools::bitmapFromVCLBitmapEx(): "
diff --git a/chart2/source/inc/NameContainer.hxx b/chart2/source/inc/NameContainer.hxx
index a5b4623..aac5a4f 100644
--- a/chart2/source/inc/NameContainer.hxx
+++ b/chart2/source/inc/NameContainer.hxx
@@ -76,7 +76,7 @@ public:
     virtual ::com::sun::star::uno::Reference< ::com::sun::star::util::XCloneable > SAL_CALL createClone() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
 
 private: //methods
-    NameContainer();//no default contructor
+    NameContainer();//no default constructor
 
 private: //member
     const ::com::sun::star::uno::Type   m_aType;
diff --git a/cppu/source/typelib/typelib.cxx b/cppu/source/typelib/typelib.cxx
index 223549e..17fc099 100644
--- a/cppu/source/typelib/typelib.cxx
+++ b/cppu/source/typelib/typelib.cxx
@@ -2240,8 +2240,8 @@ extern "C" void SAL_CALL typelib_typedescriptionreference_getDescription(
         else
         {
             (void)osl_atomic_decrement( &pRef->pType->nRefCount );
-            // detruction of this type in progress (another thread!)
-            // no acces through this weak reference
+            // destruction of this type in progress (another thread!)
+            // no access through this weak reference
             pRef->pType = 0;
         }
     }
@@ -2280,8 +2280,8 @@ extern "C" void SAL_CALL typelib_typedescriptionreference_getByName(
             }
             else
             {
-                // detruction of this type in progress (another thread!)
-                // no acces through this weak reference
+                // destruction of this type in progress (another thread!)
+                // no access through this weak reference
                 (void)osl_atomic_decrement( &(*aIt).second->nRefCount );
             }
         }
diff --git a/cppuhelper/source/propshlp.cxx b/cppuhelper/source/propshlp.cxx
index 0f1239d..62ad4c6 100644
--- a/cppuhelper/source/propshlp.cxx
+++ b/cppuhelper/source/propshlp.cxx
@@ -94,7 +94,7 @@ OPropertySetHelperInfo_Impl::OPropertySetHelperInfo_Impl(
 }
 
 /**
- * Return the sequence of properties, which are provided throug the constructor.
+ * Return the sequence of properties, which are provided through the constructor.
  */
 Sequence< Property > OPropertySetHelperInfo_Impl::getProperties(void) throw(::com::sun::star::uno::RuntimeException, std::exception)
 {
@@ -102,7 +102,7 @@ Sequence< Property > OPropertySetHelperInfo_Impl::getProperties(void) throw(::co
 }
 
 /**
- * Return the sequence of properties, which are provided throug the constructor.
+ * Return the sequence of properties, which are provided through the constructor.
  */
 Property OPropertySetHelperInfo_Impl::getPropertyByName( const OUString & PropertyName ) throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::uno::RuntimeException, std::exception)
 {
@@ -118,7 +118,7 @@ Property OPropertySetHelperInfo_Impl::getPropertyByName( const OUString & Proper
 }
 
 /**
- * Return the sequence of properties, which are provided throug the constructor.
+ * Return the sequence of properties, which are provided through the constructor.
  */
 sal_Bool OPropertySetHelperInfo_Impl::hasPropertyByName( const OUString & PropertyName ) throw(::com::sun::star::uno::RuntimeException, std::exception)
 {
diff --git a/cui/source/dialogs/cuihyperdlg.cxx b/cui/source/dialogs/cuihyperdlg.cxx
index f9888f3..afcfc3a 100644
--- a/cui/source/dialogs/cuihyperdlg.cxx
+++ b/cui/source/dialogs/cuihyperdlg.cxx
@@ -77,7 +77,7 @@ void SvxHlinkCtrl::StateChanged( sal_uInt16 nSID, SfxItemState eState,
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 
@@ -203,7 +203,7 @@ void SvxHpLinkDlg::Apply()
 
 /*************************************************************************
 |*
-|* When extrawindow is visible and its never moved by user, then move that
+|* When extra window is visible and its never moved by user, then move that
 |* window, too.
 |*
 |************************************************************************/
diff --git a/cui/source/dialogs/hldocntp.cxx b/cui/source/dialogs/hldocntp.cxx
index a51f603..7f98885 100644
--- a/cui/source/dialogs/hldocntp.cxx
+++ b/cui/source/dialogs/hldocntp.cxx
@@ -93,7 +93,7 @@ bool SvxHyperlinkNewDocTp::ImplGetURLObject( const OUString& rPath, const OUStri
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 
diff --git a/cui/source/dialogs/hldoctp.cxx b/cui/source/dialogs/hldoctp.cxx
index ce04b68..80cc05b 100644
--- a/cui/source/dialogs/hldoctp.cxx
+++ b/cui/source/dialogs/hldoctp.cxx
@@ -30,7 +30,7 @@ sal_Char const sFileScheme[]    = INET_FILE_SCHEME;
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 
diff --git a/cui/source/dialogs/hlmailtp.cxx b/cui/source/dialogs/hlmailtp.cxx
index 8e74037..cf7d957 100644
--- a/cui/source/dialogs/hlmailtp.cxx
+++ b/cui/source/dialogs/hlmailtp.cxx
@@ -33,7 +33,7 @@ using namespace ::com::sun::star;
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 
diff --git a/cui/source/dialogs/hlmarkwn.cxx b/cui/source/dialogs/hlmarkwn.cxx
index 073f498..9bfb834 100644
--- a/cui/source/dialogs/hlmarkwn.cxx
+++ b/cui/source/dialogs/hlmarkwn.cxx
@@ -123,7 +123,7 @@ void SvxHlmarkTreeLBox::Paint( const Rectangle& rRect )
 
 /*************************************************************************
 |*
-|* Contructor / Destructor
+|* Constructor / Destructor
 |*
 |************************************************************************/
 SvxHlinkDlgMarkWnd::SvxHlinkDlgMarkWnd( SvxHyperlinkTabPageBase *pParent )
diff --git a/dbaccess/source/ui/inc/RelationDlg.hxx b/dbaccess/source/ui/inc/RelationDlg.hxx
index 1868552..5950d64 100644
--- a/dbaccess/source/ui/inc/RelationDlg.hxx
+++ b/dbaccess/source/ui/inc/RelationDlg.hxx
@@ -66,13 +66,13 @@ namespace dbaui
 
         virtual short Execute() SAL_OVERRIDE;
 
-        /** getTableMap gives acces to the table window map
+        /** getTableMap gives access to the table window map
             @retrun the table window from the join view
         */
         OJoinTableView::OTableWindowMap* getTableMap() const { return m_pTableMap; }
 
         /** getConnectionData returns the current connection data
-            @return the current connectiondata
+            @return the current connection data
         */
         virtual TTableConnectionData::value_type getConnectionData() const SAL_OVERRIDE;
 
diff --git a/dbaccess/source/ui/inc/ScrollHelper.hxx b/dbaccess/source/ui/inc/ScrollHelper.hxx
index 9a8dc10..cf27cba 100644
--- a/dbaccess/source/ui/inc/ScrollHelper.hxx
+++ b/dbaccess/source/ui/inc/ScrollHelper.hxx
@@ -30,7 +30,7 @@ namespace dbaui
         Link    m_aUpScroll;
         Link    m_aDownScroll;
     public:
-        /** default contructor
+        /** default constructor
         */
         OScrollHelper();
 
diff --git a/dbaccess/source/ui/inc/UITools.hxx b/dbaccess/source/ui/inc/UITools.hxx
index ec38498..b828f20 100644
--- a/dbaccess/source/ui/inc/UITools.hxx
+++ b/dbaccess/source/ui/inc/UITools.hxx
@@ -111,7 +111,7 @@ namespace dbaui
                     const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& _rxContext);
 
     /** fills a map and a vector with localized type names
-        @param  _rxConnection   the connection to acces the metadata
+        @param  _rxConnection   the connection to access the metadata
         @param  _rsTypeNames    a list of localized type names separated with ';'
         @param  _rTypeInfoMap   the filled map with the type names
         @param  _rTypeInfoIters the vector filled with map iterators
diff --git a/desktop/test/deployment/options/handler/com/sun/star/comp/extensionoptions/OptionsEventHandler.java b/desktop/test/deployment/options/handler/com/sun/star/comp/extensionoptions/OptionsEventHandler.java
index 17c6244..8e7d4cb 100644
--- a/desktop/test/deployment/options/handler/com/sun/star/comp/extensionoptions/OptionsEventHandler.java
+++ b/desktop/test/deployment/options/handler/com/sun/star/comp/extensionoptions/OptionsEventHandler.java
@@ -256,7 +256,7 @@ public class OptionsEventHandler {
                 throw new com.sun.star.lang.IllegalArgumentException(
                     "The window is not supported by this handler", this, (short) -1);
 
-            //To acces the separate controls of the window we need to obtain the
+            //To access the separate controls of the window we need to obtain the
             //XControlContainer from window implementation
             XControlContainer xContainer = UnoRuntime.queryInterface(
                 XControlContainer.class, aWindow);
diff --git a/filter/source/pdf/pdfexport.cxx b/filter/source/pdf/pdfexport.cxx
index e2f5773..19e3f18 100644
--- a/filter/source/pdf/pdfexport.cxx
+++ b/filter/source/pdf/pdfexport.cxx
@@ -582,7 +582,7 @@ bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue >&
                 break;
             }
 
-//copy in context the values default in the contructor or set by the FilterData sequence of properties
+//copy in context the values default in the constructor or set by the FilterData sequence of properties
             aContext.Tagged     = mbUseTaggedPDF;
 
 //values used in viewer
diff --git a/framework/source/fwi/uielement/constitemcontainer.cxx b/framework/source/fwi/uielement/constitemcontainer.cxx
index 79a0141..93eb992 100644
--- a/framework/source/fwi/uielement/constitemcontainer.cxx
+++ b/framework/source/fwi/uielement/constitemcontainer.cxx
@@ -76,7 +76,7 @@ OPropertySetHelperInfo_Impl::OPropertySetHelperInfo_Impl(
 }
 
 /**
- * Return the sequence of properties, which are provided throug the constructor.
+ * Return the sequence of properties, which are provided through the constructor.
  */
 Sequence< Property > OPropertySetHelperInfo_Impl::getProperties(void) throw(::com::sun::star::uno::RuntimeException, std::exception)
 {
@@ -84,7 +84,7 @@ Sequence< Property > OPropertySetHelperInfo_Impl::getProperties(void) throw(::co
 }
 
 /**
- * Return the sequence of properties, which are provided throug the constructor.
+ * Return the sequence of properties, which are provided through the constructor.
  */
 Property OPropertySetHelperInfo_Impl::getPropertyByName( const OUString & PropertyName ) throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::uno::RuntimeException, std::exception)
 {
@@ -100,7 +100,7 @@ Property OPropertySetHelperInfo_Impl::getPropertyByName( const OUString & Proper
 }
 
 /**
- * Return the sequence of properties, which are provided throug the constructor.
+ * Return the sequence of properties, which are provided through the constructor.
  */
 sal_Bool OPropertySetHelperInfo_Impl::hasPropertyByName( const OUString & PropertyName ) throw(::com::sun::star::uno::RuntimeException, std::exception)
 {
diff --git a/include/cppuhelper/propshlp.hxx b/include/cppuhelper/propshlp.hxx
index c6dcfd1..933e002 100644
--- a/include/cppuhelper/propshlp.hxx
+++ b/include/cppuhelper/propshlp.hxx
@@ -65,7 +65,7 @@ public:
        Return the property members Name and Attribute from the handle nHandle.
        @param nHandle   the handle of a property. If the values of the handles
                           are sorted in the same way as the names and the highest handle value
-                          is getCount() -1, than it must be an indexed acces to the property array.
+                          is getCount() -1, than it must be an indexed access to the property array.
        @param pPropName is an out parameter filled with property name of the property with the
                               handle nHandle. May be NULL.
        @param pAttributes is an out parameter filled with attributes of the property with the
@@ -144,7 +144,7 @@ public:
        Return the property members Name and Attribute from the handle nHandle.
        @param nHandle   the handle of a property. If the values of the handles
                           are sorted in the same way as the names and the highest handle value
-                          is getCount() -1, than it is only an indexed acces to the property array.
+                          is getCount() -1, than it is only an indexed access to the property array.
                           Otherwise it is a linear search through the array.
        @param pPropName is an out parameter filled with property name of the property with the
                               handle nHandle. May be NULL.
diff --git a/include/rtl/strbuf.hxx b/include/rtl/strbuf.hxx
index b2ad147..52d29ca 100644
--- a/include/rtl/strbuf.hxx
+++ b/include/rtl/strbuf.hxx
@@ -240,7 +240,7 @@ public:
     /**
         Fill the string data in the new string and clear the buffer.
 
-        This method is more efficient than the contructor of the string. It does
+        This method is more efficient than the constructor of the string. It does
         not copy the buffer.
 
         @return the string previously contained in the buffer.
diff --git a/include/rtl/ustrbuf.hxx b/include/rtl/ustrbuf.hxx
index 179ba82..abb85a0 100644
--- a/include/rtl/ustrbuf.hxx
+++ b/include/rtl/ustrbuf.hxx
@@ -210,7 +210,7 @@ public:
     /**
         Fill the string data in the new string and clear the buffer.
 
-        This method is more efficient than the contructor of the string. It does
+        This method is more efficient than the constructor of the string. It does
         not copy the buffer.
 
         @return the string previously contained in the buffer.
diff --git a/include/sfx2/sfxuno.hxx b/include/sfx2/sfxuno.hxx
index c8264bd..2e773ed 100644
--- a/include/sfx2/sfxuno.hxx
+++ b/include/sfx2/sfxuno.hxx
@@ -68,7 +68,7 @@ typedef sal_Int32 FrameSearchFlags;
 //  macros for declaration and definition of uno-services
 
 //  declaration of      XInterface::queryInterface()
-//                      XInterface::aquire()
+//                      XInterface::acquire()
 //                      XInterface::release()
 //                      XTypeProvider::getTypes()
 //                      XTypeProvider::getImplementationId()
diff --git a/include/svx/sdr/overlay/overlayobject.hxx b/include/svx/sdr/overlay/overlayobject.hxx
index 7d803a2..b663ec5 100644
--- a/include/svx/sdr/overlay/overlayobject.hxx
+++ b/include/svx/sdr/overlay/overlayobject.hxx
@@ -156,7 +156,7 @@ namespace sdr
             // implementation does nothing and does not create a new event.
             virtual void Trigger(sal_uInt32 nTime) SAL_OVERRIDE;
 
-            // acces to AllowsAnimation flag
+            // access to AllowsAnimation flag
             bool allowsAnimation() const { return mbAllowsAnimation; }
 
             // stripe definition has changed. The OverlayManager does have
diff --git a/reportbuilder/java/org/libreoffice/report/InputRepository.java b/reportbuilder/java/org/libreoffice/report/InputRepository.java
index 8582106..0d89b2d 100644
--- a/reportbuilder/java/org/libreoffice/report/InputRepository.java
+++ b/reportbuilder/java/org/libreoffice/report/InputRepository.java
@@ -45,7 +45,7 @@ public interface InputRepository
 
     InputStream createInputStream(final String name) throws IOException;
 
-    /** allows to acces sub repositories inside this repository
+    /** allows to access sub repositories inside this repository
      *
      * @param name describes the path to the sub repository
      * @return the sub repository
diff --git a/reportbuilder/java/org/libreoffice/report/OutputRepository.java b/reportbuilder/java/org/libreoffice/report/OutputRepository.java
index b7be98d..62c1243 100644
--- a/reportbuilder/java/org/libreoffice/report/OutputRepository.java
+++ b/reportbuilder/java/org/libreoffice/report/OutputRepository.java
@@ -42,7 +42,7 @@ public interface OutputRepository
      */
     OutputStream createOutputStream(final String name, final String mimeType) throws IOException;
 
-    /** allows to acces sub repositories inside this repository
+    /** allows to access sub repositories inside this repository
      *
      * @param name describes the path to the sub repository
      * @param mimeType
diff --git a/sc/source/ui/view/printfun.cxx b/sc/source/ui/view/printfun.cxx
index 0a92dc3..cf4d8e8 100644
--- a/sc/source/ui/view/printfun.cxx
+++ b/sc/source/ui/view/printfun.cxx
@@ -931,7 +931,7 @@ void ScPrintFunc::InitParam( const ScPrintOptions* pOptions )
 
     // TabPage "Parts":
 
-    //! walk throuch all PrintAreas of the table !!!
+    //! walk through all PrintAreas of the table !!!
     const ScRange*  pPrintArea = pDoc->GetPrintRange( nPrintTab, 0 );
     const ScRange*  pRepeatCol = pDoc->GetRepeatColRange( nPrintTab );
     const ScRange*  pRepeatRow = pDoc->GetRepeatRowRange( nPrintTab );
@@ -2247,7 +2247,7 @@ void ScPrintFunc::PrintPage( long nPageNo, SCCOL nX1, SCROW nY1, SCCOL nX2, SCRO
         LocateArea( nX1,nY1, nX2,nY2, nDataX,nDataY, false,false, *pLocationData );
 
     //  output column/row headers
-    //  after data (throug probably shadow)
+    //  after data (through probably shadow)
 
     Color aGridColor( COL_BLACK );
     if ( bUseStyleColor )
diff --git a/sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx b/sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx
index b0dec62..3678648 100644
--- a/sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx
+++ b/sd/source/ui/slidesorter/inc/cache/SlsCacheContext.hxx
@@ -86,7 +86,7 @@ public:
 
     /** Return the model to which the pages belong for which the called
         cache manages the previews.  Different caches that belong to the
-        same model but have different preview sizes may acces previews of
+        same model but have different preview sizes may access previews of
         each other in order to create fast previews of the previews.
     */
     virtual ::com::sun::star::uno::Reference<com::sun::star::uno::XInterface> GetModel (void) = 0;
diff --git a/stoc/source/javaloader/javaloader.cxx b/stoc/source/javaloader/javaloader.cxx
index c4d78d0..a3bb06f 100644
--- a/stoc/source/javaloader/javaloader.cxx
+++ b/stoc/source/javaloader/javaloader.cxx
@@ -221,7 +221,7 @@ const css::uno::Reference<XImplementationLoader> & JavaComponentLoader::getJavaL
                 throw RuntimeException(
                     "javaloader error - no Java environment available");
 
-            // why is there no convinient contructor?
+            // why is there no convenient constructor?
             OUString sCppu_current_lb_name(CPPU_CURRENT_LANGUAGE_BINDING_NAME);
             uno_getEnvironment(&pUno_environment, sCppu_current_lb_name.pData, NULL);
             if(!pUno_environment)
diff --git a/svx/sdi/fmslots.sdi b/svx/sdi/fmslots.sdi
index af34d7b..255fa88 100644
--- a/svx/sdi/fmslots.sdi
+++ b/svx/sdi/fmslots.sdi
@@ -547,7 +547,7 @@ interface FormTextAttributeShell
     /**** <HACK> ****/
     // the following is a slight hack. Problem is that the form shell needs to translate
     // slot names/args into URL dispatch names/args. For this, the SfxSlotPool is used
-    // - it provides convinient methods for this. However, the "pool" is not really a
+    // - it provides convenient methods for this. However, the "pool" is not really a
     // "pool" - it only knows slots, if there is a shell on the dispatcher stack which
     // which is responsible for this slot.
     // So, we declare the form shell as responsible for the following slots.
diff --git a/svx/source/fmcomp/gridctrl.cxx b/svx/source/fmcomp/gridctrl.cxx
index 4eeb547..cdf417c 100644
--- a/svx/source/fmcomp/gridctrl.cxx
+++ b/svx/source/fmcomp/gridctrl.cxx
@@ -3582,7 +3582,7 @@ void DbGridControl::disposing(sal_uInt16 _nId, const EventObject& /*_rEvt*/)
     if (_nId == 0)
     {   // the seek cursor is being disposed
         ::osl::MutexGuard aGuard(m_aAdjustSafety);
-        setDataSource(NULL,0); // our clone was disposed so we set our datasource to null to avoid later acces to it
+        setDataSource(NULL,0); // our clone was disposed so we set our datasource to null to avoid later access to it
         if (m_nAsynAdjustEvent)
         {
             RemoveUserEvent(m_nAsynAdjustEvent);
diff --git a/sw/inc/tox.hxx b/sw/inc/tox.hxx
index 6a4866c..50c1c32 100644
--- a/sw/inc/tox.hxx
+++ b/sw/inc/tox.hxx
@@ -264,7 +264,7 @@ class SW_DLLPUBLIC SwFormTokensHelper
 
 public:
     /**
-       contructor
+       constructor
 
        @param rTokens       vector of tokens
     */
diff --git a/sw/source/core/inc/ptqueue.hxx b/sw/source/core/inc/ptqueue.hxx
index bed8905..096786b 100644
--- a/sw/source/core/inc/ptqueue.hxx
+++ b/sw/source/core/inc/ptqueue.hxx
@@ -33,7 +33,7 @@
  * Invalidating windows directly from the RootFrm::Paint was not a successful
  * approach, because the Paint()s arrive at a very unfavourable point in time.
  * Triggering an update for all windows after printing each page does not seem
- * appropriate either: on the one hand we don't have direct acces to the edit
+ * appropriate either: on the one hand we don't have direct access to the edit
  * windows and on the other hand the updates can become very costly on some
  * platforms.
  */
diff --git a/sw/source/uibase/app/docsh2.cxx b/sw/source/uibase/app/docsh2.cxx
index ba1b023..71187d4 100644
--- a/sw/source/uibase/app/docsh2.cxx
+++ b/sw/source/uibase/app/docsh2.cxx
@@ -1003,7 +1003,7 @@ void SwDocShell::Execute(SfxRequest& rReq)
                         }
                         catch (const Exception&)
                         {
-                            OSL_FAIL("control acces failed");
+                            OSL_FAIL("control access failed");
                         }
 
                         xFP->setTitle( SW_RESSTR( nStrId ));
diff --git a/sw/source/uibase/uiview/view2.cxx b/sw/source/uibase/uiview/view2.cxx
index be7e8ec..ace661a 100644
--- a/sw/source/uibase/uiview/view2.cxx
+++ b/sw/source/uibase/uiview/view2.cxx
@@ -357,7 +357,7 @@ bool SwView::InsertGraphicDlg( SfxRequest& rReq )
     }
     catch (const Exception&)
     {
-        OSL_FAIL("control acces failed");
+        OSL_FAIL("control access failed");
     }
 
     SFX_REQUEST_ARG( rReq, pName, SfxStringItem, SID_INSERT_GRAPHIC , false );
diff --git a/toolkit/source/awt/vclxtoolkit.cxx b/toolkit/source/awt/vclxtoolkit.cxx
index 70e7b8e..389fa0d 100644
--- a/toolkit/source/awt/vclxtoolkit.cxx
+++ b/toolkit/source/awt/vclxtoolkit.cxx
@@ -624,7 +624,7 @@ static void SAL_CALL ToolkitWorkerFunction( void* pArgs )
 }
 }
 
-// contructor, which might initialize VCL
+// constructor, which might initialize VCL
 VCLXToolkit::VCLXToolkit():
     cppu::WeakComponentImplHelper2<
     ::com::sun::star::awt::XToolkitExperimental,
diff --git a/unotools/source/config/fontoptions.cxx b/unotools/source/config/fontoptions.cxx
index 2541c27..b7c26f7 100644
--- a/unotools/source/config/fontoptions.cxx
+++ b/unotools/source/config/fontoptions.cxx
@@ -75,7 +75,7 @@ class SvtFontOptions_Impl : public ConfigItem
 
         /*-****************************************************************************************************
             @short      access method to get internal values
-            @descr      These method give us a chance to regulate acces to our internal values.
+            @descr      These method give us a chance to regulate access to our internal values.
                         It's not used in the moment - but it's possible for the feature!
         *//*-*****************************************************************************************************/
 
diff --git a/unotools/source/config/localisationoptions.cxx b/unotools/source/config/localisationoptions.cxx
index 2ad2ee1..7fd2440 100644
--- a/unotools/source/config/localisationoptions.cxx
+++ b/unotools/source/config/localisationoptions.cxx
@@ -74,7 +74,7 @@ class SvtLocalisationOptions_Impl : public ConfigItem
 
         /*-****************************************************************************************************
             @short      access method to get internal values
-            @descr      These method give us a chance to regulate acces to our internal values.
+            @descr      These method give us a chance to regulate access to our internal values.
                         It's not used in the moment - but it's possible for the feature!
         *//*-*****************************************************************************************************/
 


More information about the Libreoffice-commits mailing list
diff --git a/framework/inc/macros/xinterface.hxx b/framework/inc/macros/xinterface.hxx
index 8354a9c..2c2f378 100644
--- a/framework/inc/macros/xinterface.hxx
+++ b/framework/inc/macros/xinterface.hxx
@@ -46,10 +46,10 @@ namespace framework{
 _________________________________________________________________________________________________________________*/
 
 //  private
 //  implementation of   XInterface::aquire()
 //                      XInterface::release()
 
-#define PRIVATE_DEFINE_XINTERFACE_AQUIRE_RELEASE( CLASS, BASECLASS )                                                                                        \
+#define PRIVATE_DEFINE_XINTERFACE_ACQUIRE_RELEASE( CLASS, BASECLASS )                                                                                        \
     void SAL_CALL CLASS::acquire() throw()                                                                          \
     {                                                                                                                                                       \
         /* Don't use mutex in methods of XInterface! */                                                                                                     \
@@ -124,15 +124,15 @@ ________________________________________________________________________________
 //  complete implementation of XInterface for different use cases
 
 #define PRIVATE_DEFINE_XINTERFACE_PURE( CLASS, BASECLASS )                                                                                                  \
-    PRIVATE_DEFINE_XINTERFACE_AQUIRE_RELEASE( CLASS, BASECLASS )                                                                                            \
+    PRIVATE_DEFINE_XINTERFACE_ACQUIRE_RELEASE( CLASS, BASECLASS )                                                                                            \
     PRIVATE_DEFINE_XINTERFACE_QUERYINTERFACE_PURE( CLASS, BASECLASS )
 
 #define PRIVATE_DEFINE_XINTERFACE( CLASS, BASECLASS, INTERFACES )                                                                                           \
-    PRIVATE_DEFINE_XINTERFACE_AQUIRE_RELEASE( CLASS, BASECLASS )                                                                                            \
+    PRIVATE_DEFINE_XINTERFACE_ACQUIRE_RELEASE( CLASS, BASECLASS )                                                                                            \
     PRIVATE_DEFINE_XINTERFACE_QUERYINTERFACE( CLASS, BASECLASS, INTERFACES )
 
 #define PRIVATE_DEFINE_XINTERFACE_LARGE( CLASS, BASECLASS, INTERFACES_FIRST, INTERFACES_SECOND )                                                            \
-    PRIVATE_DEFINE_XINTERFACE_AQUIRE_RELEASE( CLASS, BASECLASS )                                                                                            \
+    PRIVATE_DEFINE_XINTERFACE_ACQUIRE_RELEASE( CLASS, BASECLASS )                                                                                            \
     PRIVATE_DEFINE_XINTERFACE_QUERYINTERFACE_LARGE( CLASS, BASECLASS, INTERFACES_FIRST, INTERFACES_SECOND )
 
 //  private
@@ -46,10 +46,10 @@ namespace framework{
 
 //  private
-//  implementation of   XInterface::aquire()
+//  implementation of   XInterface::acquire()
 //                      XInterface::release()
 